@@ -35,13 +35,17 @@ class H5Dataset(Dataset):
 
     def __init__(self, schema, save_filename, data_iter=None,
         data_length=None, chunk_size=300, compression=None, 
-        transform=None, append_mode=False, verbose=0):
+        transform=None, append_mode=False, verbose=0, 
+        to_memory=False, multiprocess=False):
 
         '''
         Note: 
             * data length must be known value otherwise chunk size will not be enabled
             * chunk size affects reading speed, usually a size of 100-500 is suitable value
             * compression algorithm affects reading speed, so if storage is not your concern is recommended not to enable
+        multiprocess: 
+            if such error occur  "OSError: Can't read data (address of object past end of allocation)"
+            set it to True
         '''
 
         # normalized schema design to dictionary
@@ -59,11 +63,22 @@ class H5Dataset(Dataset):
         if not os.path.exists(self.save_filename):
             self.preprocess(data_iter)
 
-        self.reader = h5.File(self.save_filename, 'r')
+        if multiprocess:
+            self.reader = h5.File(AtomicFile(self.save_filename), 'r')
+        else:
+            self.reader = h5.File(self.save_filename, 'r')
+
         first_key = list(self.schema.keys())[0]
         self.num_entries = self.reader[first_key].shape[0]
 
 
+        if to_memory:
+            # warning this may use all your memory
+            temp = {}
+            for key in self.schema.keys():
+                temp[key] = self.reader[key][:]
+            self.reader = temp
+
     def preprocess(self, data_iter):
         idx = 0
         for data in data_iter:
